@@ -315,7 +315,6 @@ BrowserRun::NonEmbeddableResult BrowserRun::handleNonEmbeddable(const QString &_
         return Handled;
     }
 
-    KIO::Scheduler::publishSlaveOnHold(); // publish any slave on hold so it can be reused.
     return NotHandled;
 }
 
@@ -397,7 +396,7 @@ void KParts::BrowserRun::saveUrl(const QUrl &url, const QString &suggestedFileNa
             if (QStandardPaths::findExecutable(downloadManager).isEmpty()) {
                 QString errMsg = i18n("The Download Manager (%1) could not be found in your $PATH ", downloadManager);
                 QString errMsgEx = i18n("Try to reinstall it  \n\nThe integration with Konqueror will be disabled.");
-                KMessageBox::detailedSorry(nullptr, errMsg, errMsgEx);
+                KMessageBox::detailedError(nullptr, errMsg, errMsgEx);
                 cfg.writePathEntry("DownloadManager", QString());
                 cfg.sync();
             } else {
@@ -408,8 +407,6 @@ void KParts::BrowserRun::saveUrl(const QUrl &url, const QString &suggestedFileNa
                 }
 
                 // qDebug() << "Calling command" << downloadManager << args;
-                // slave is already on hold (slotBrowserMimetype())
-                KIO::Scheduler::publishSlaveOnHold();
 
                 auto *job = new KIO::CommandLauncherJob(downloadManager, args);
                 job->setExecutable(downloadManager);
